# Kerberos authentication for Yamcs Client Library
[![PyPI](https://img.shields.io/pypi/v/yamcs-client-kerberos.svg)](https://pypi.python.org/pypi/yamcs-client-kerberos)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/yamcs-client-kerberos.svg)](https://pypi.python.org/pypi/yamcs-client-kerberos/)
